using FitConnect;
using FitConnect.Models;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;

namespace DemoRunner;

public static class SubscriberDemo {
    public static async Task Run(IConfiguration config, ILogger logger) {
        var clientId = config["FitConnect:Subscriber:ClientId"];
        var clientSecret = config["FitConnect:Subscriber:ClientSecret"];
        var destinationId = config["FitConnect:Subscriber:DestinationId"];
        var privateKeyDecryption = config["FitConnect:Subscriber:PrivateKeyDecryption"];
        var privateKeySigning = config["FitConnect:Subscriber:PrivateKeySigning"];
        var publicKeyEncryption = config["FitConnect:Subscriber:PublicKeyEncryption"];
        var publicKeySignatureVerification =
            config["FitConnect:Subscriber:PublicKeySignatureVerification"];
        var setPublicKey = config["FitConnect:Subscriber:SetPublicKey"];


        OutputHelper.PrintSubscriber();

        var subscriber = Client.GetSubscriber(FitConnectEnvironment.Testing, clientId,
            clientSecret,
            await File.ReadAllTextAsync(privateKeyDecryption),
            await File.ReadAllTextAsync(privateKeySigning),
            await File.ReadAllTextAsync(publicKeyEncryption),
            await File.ReadAllTextAsync(publicKeySignatureVerification),
            logger);

        var submissions = await subscriber.GetAvailableSubmissionsAsync();

        foreach (var submission in submissions)
            try {
                var subscriberWithSubmission =
                   await subscriber.RequestSubmissionAsync(submission.Id);
                var attachments = await subscriberWithSubmission.GetAttachmentsAsync();

                logger.LogInformation("Fachdaten: {Data}", subscriberWithSubmission.GetDataJson());
                await subscriberWithSubmission
                    .AcceptSubmissionAsync();
            }
            catch (Exception e) {
                logger.LogError(e, "Fehler beim Abrufen der Einreichung");
            }
    }
}
